@@ -13,25 +13,27 @@ Alien::Tidyp - Build and make available tidyp library - L<http://www.tidyp.com>
 
 =cut
 
-our $VERSION = 'v1.2.3';
+our $VERSION = 'v1.2.4';
 
 =head1 VERSION
 
-Version v1.2.3 of Alien::Tidyp uses I<tidyp> sources v1.02.
+Version v1.2.4 of Alien::Tidyp uses I<tidyp> sources v1.02.
 
 =head1 SYNOPSIS
 
-Building and installing Alien::Tidyp comprise of:
+Alien::Tidyp tries (in given order) during its installation:
 
 =over
 
-=item * Downloading I<tidyp> source code tarball
+=item * Locate an already installed tidyp + ask user whether to use the already installed
+tidyp or whether to build tidyp from source codes (see the following 3 bullets)
 
-=item * Building I<tidyp> binaries from source codes
+=item * Download I<tidyp> source code tarball
 
-=item * Installing binaries and dev files (*.h, *.a) into I<share> directory of Alien::Tidyp distribution
+=item * Build I<tidyp> binaries from source codes
 
-=item * I<share> directory is usually something like this: /usr/lib/perl5/site_perl/5.10/auto/share/dist/Alien-Tidyp
+=item * Install binaries and dev files (*.h, *.a) into I<share> directory of Alien::Tidyp
+distribution - I<share> directory is usually something like this: /usr/lib/perl5/site_perl/5.10/auto/share/dist/Alien-Tidyp
 
 =back
 
@@ -49,7 +51,7 @@ I<tidyp> like this:
       INC          => Alien::Tidyp->config('INC'),
       # + additional params
     );
-    
+
 =head1 METHODS
 
 =head2 config()
@@ -132,11 +134,15 @@ acknowledgment is not required but would be appreciated.
 sub config
 {
   my ($package, $param) = @_;
-  my $share_dir = dist_dir('Alien-Tidyp');
-  my $subdir = Alien::Tidyp::ConfigData->config('share_subdir');
-  return unless $subdir;
-  my $real_prefix = catdir($share_dir, $subdir);
   return unless ($param =~ /[a-z0-9_]*/i);
+  my $subdir = Alien::Tidyp::ConfigData->config('share_subdir');
+  unless ($subdir) {
+    #we are using tidyp already installed on your system not compiled by Alien::Tidyp
+    #therefore no additinal magic needed
+    return Alien::Tidyp::ConfigData->config('config')->{$param};
+  }
+  my $share_dir = dist_dir('Alien-Tidyp');
+  my $real_prefix = catdir($share_dir, $subdir);
   my $val = Alien::Tidyp::ConfigData->config('config')->{$param};
   return unless $val;
   $val =~ s/\@PrEfIx\@/$real_prefix/g; # handle @PrEfIx@ replacement
